Module blaxel.core.client.models.volume_spec
============================================

Classes
-------

`VolumeSpec(region: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, size: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Volume specification - immutable configuration
    
    Attributes:
        region (Union[Unset, str]): Region where the volume should be created (e.g. us-pdx-1, eu-lon-1)
        size (Union[Unset, int]): Size of the volume in MB
    
    Method generated by attrs for class VolumeSpec.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `region: blaxel.core.client.types.Unset | str`
    :

    `size: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :